<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\PersonBundle\Form\DataTransformer;

use Symfony\Component\Form\DataTransformerInterface;

final class PhoneNumberTypeDataTransformer implements DataTransformerInterface
{
    private string $countryCodePrefix;

    public function __construct(string $countryCodePrefix)
    {
        $this->countryCodePrefix = $countryCodePrefix;
    }

    /**
     * @param string $phoneNumber
     */
    public function reverseTransform($phoneNumber): string
    {
        $phoneNumber = preg_replace('/[^0-9+]/', '', $phoneNumber);

        if (0 === strpos($phoneNumber, '00', 0)) {
            $phoneNumber = substr_replace($phoneNumber, '+', 0, 2);
        }

        if (0 === strpos($phoneNumber, '0', 0)) {
            $phoneNumber = substr_replace($phoneNumber, $this->countryCodePrefix, 0, 1);
        }

        return $phoneNumber;
    }

    public function transform($phoneNumber)
    {
        return $phoneNumber;
    }
}
