<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\PersonBundle\Form\Type;

use Chill\PersonBundle\Form\DataTransformer\PhoneNumberTypeDataTransformer;
use Symfony\Component\DependencyInjection\ParameterBag\ParameterBagInterface;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\TelType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;

final class PhoneNumberType extends AbstractType
{
    private ParameterBagInterface $parameterBag;

    public function __construct(ParameterBagInterface $parameterBag)
    {
        $this->parameterBag = $parameterBag;
    }

    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder
            ->addViewTransformer(
                new PhoneNumberTypeDataTransformer($options['default_country_prefix'])
            );
    }

    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver
            ->setDefined('default_country_prefix')
            ->setAllowedTypes('default_country_prefix', 'string')
            ->setDefaults([
                // TODO: Is it the best way to do that?
                'default_country_prefix' => $this->parameterBag->get('chill_main.phonenumber_default_country_code') ?? '+32',
            ]);
    }

    public function getParent(): string
    {
        return TelType::class;
    }
}
