<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\PersonBundle\Security\Authorization;

use Chill\PersonBundle\Entity\AccompanyingPeriod\AccompanyingPeriodWork;
use Symfony\Component\Security\Core\Authentication\Token\TokenInterface;
use Symfony\Component\Security\Core\Authorization\Voter\Voter;
use Symfony\Component\Security\Core\Security;
use UnexpectedValueException;
use function in_array;

class AccompanyingPeriodWorkVoter extends Voter
{
    public const SEE = 'CHILL_MAIN_ACCOMPANYING_PERIOD_WORK_SEE';

    private Security $security;

    public function __construct(Security $security)
    {
        $this->security = $security;
    }

    protected function supports($attribute, $subject): bool
    {
        return $subject instanceof AccompanyingPeriodWork
            && in_array($attribute, $this->getRoles(), true);
    }

    /**
     * @param string $attribute
     * @param AccompanyingPeriodWork $subject
     */
    protected function voteOnAttribute($attribute, $subject, TokenInterface $token): bool
    {
        switch ($attribute) {
            case self::SEE:
                return $this->security->isGranted(AccompanyingPeriodVoter::SEE, $subject->getAccompanyingPeriod());

            default:
                throw new UnexpectedValueException("attribute {$attribute} is not supported");
        }
    }

    private function getRoles(): array
    {
        return [self::SEE];
    }
}
