<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\PersonBundle\Tests\Form\Type;

use Chill\PersonBundle\Form\Type\PhoneNumberType;
use Locale;
use Symfony\Component\DependencyInjection\ParameterBag\ParameterBagInterface;
use Symfony\Component\Form\PreloadedExtension;
use Symfony\Component\Form\Test\TypeTestCase;

/**
 * @internal
 * @coversNothing
 */
final class PhoneNumberTypeTest extends TypeTestCase
{
    private ParameterBagInterface $parameterBag;

    protected function setUp(): void
    {
        Locale::setDefault('en');

        // mock any dependencies
        $this->parameterBag = $this->createMock(ParameterBagInterface::class);

        // Mandatory
        parent::setUp();
    }

    public function singleFieldProvider()
    {
        yield ['abc', [], ''];

        yield ['abc', ['default_country_prefix' => '+34'], ''];

        yield ['123', [], '123'];

        yield ['0,-03f212@%3g4 g5k 6789', [], '+32123456789'];

        yield ['0032 123456789', [], '+32123456789'];

        yield ['+32 123456789', ['default_country_prefix' => '+34'], '+32123456789'];

        yield ['0123456789', ['default_country_prefix' => '+33'], '+33123456789'];

        yield ['0486/540660', [], '+32486540660'];

        yield ['0486/540.660', ['default_country_prefix' => '+36'], '+36486540660'];
    }

    /**
     * @dataProvider singleFieldProvider
     */
    public function testSingleField(string $input, array $options, string $output)
    {
        $form = $this->factory->create(PhoneNumberType::class, null, $options);

        $form->submit($input);

        if (method_exists($form, 'getTransformationFailure') && $failure = $form->getTransformationFailure()) {
            throw $failure;
        }

        self::assertTrue($form->isSynchronized());

        $view = $form->createView();

        self::assertSame($output, $view->vars['value']);
    }

    protected function getExtensions()
    {
        // create a type instance with the mocked dependencies
        $type = new PhoneNumberType($this->parameterBag);

        return [
            new PreloadedExtension([$type], []),
        ];
    }
}
